OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "No s'ha pogut enviar correu als usuaris següents: %s",
    "Preparing update" : "Preparant l'actualització",
    "Turned on maintenance mode" : "Activat el mode de manteniment",
    "Turned off maintenance mode" : "Desactivat el mode de manteniment",
    "Maintenance mode is kept active" : "El mode de manteniment es manté activat",
    "Updated database" : "Actualitzada la base de dades",
    "Checked database schema update" : "S'ha comprobat l'actualització de l'esquema de la base de dades",
    "Checked database schema update for apps" : "S'ha comprobat l'actualització de l'esquema de la base de dades per les apps",
    "Updated \"%s\" to %s" : "Actualitzat \"%s\" a %s",
    "Repair warning: " : "Advertiment de reparació:",
    "Repair error: " : "Error de reparació:",
    "Following apps have been disabled: %s" : "Les aplicacions següents s'han deshabilitat: %s",
    "Already up to date" : "Ja actualitzat",
    "File is too big" : "El fitxer és massa gran",
    "Invalid file provided" : "L'arxiu proporcionat no és vàlid",
    "No image or file provided" : "No s'han proporcionat imatges o fitxers",
    "Unknown filetype" : "Tipus de fitxer desconegut",
    "Invalid image" : "Imatge no vàlida",
    "No temporary profile picture available, try again" : "No hi ha imatge temporal de perfil disponible, torneu a intentar-ho",
    "No crop data provided" : "No heu proporcionat dades del retall",
    "No valid crop data provided" : "Les dades del retall proporcionades no són vàlides",
    "Crop is not square" : "El retall no és quadrat",
    "Couldn't reset password because the token is invalid" : "No es pot restablir la contrasenya perquè el testimoni no és vàlid",
    "Couldn't reset password because the token is expired" : "No es pot restablir la contrasenya perquè el testimoni ha vençut",
    "Couldn't send reset email. Please make sure your username is correct." : "No s'ha pogut enviar el correu de restabliment. Assegureu-vos que el vostre nom d'usuari és correcte.",
    "%s password reset" : "restableix la contrasenya %s",
    "Couldn't send reset email. Please contact your administrator." : "No s'ha pogut restablir el correu. Contacteu amb l'administrador.",
    "Sunday" : "Diumenge",
    "Monday" : "Dilluns",
    "Tuesday" : "Dimarts",
    "Wednesday" : "Dimecres",
    "Thursday" : "Dijous",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sun." : "Dg.",
    "Mon." : "Dl.",
    "Tue." : "Dm.",
    "Wed." : "Dc.",
    "Thu." : "Dj.",
    "Fri." : "Dv.",
    "Sat." : "Ds.",
    "Su" : "Dg",
    "Mo" : "Dl",
    "Tu" : "Dm",
    "We" : "Dc",
    "Th" : "Dj",
    "Fr" : "Dv",
    "Sa" : "Ds",
    "January" : "Gener",
    "February" : "Febrer",
    "March" : "Març",
    "April" : "Abril",
    "May" : "Maig",
    "June" : "Juny",
    "July" : "Juliol",
    "August" : "Agost",
    "September" : "Setembre",
    "October" : "Octubre",
    "November" : "Novembre",
    "December" : "Desembre",
    "Jan." : "Gen.",
    "Feb." : "Febr.",
    "Mar." : "Març",
    "Apr." : "Abr.",
    "May." : "Maig",
    "Jun." : "Juny",
    "Jul." : "Jul.",
    "Aug." : "Ag.",
    "Sep." : "Set.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "Settings" : "Configuració",
    "Saving..." : "Desant...",
    "seconds ago" : "segons enrere",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "L'enllaç per reiniciar la vostra contrasenya s'ha enviat al vostre correu. Si no el rebeu en un temps raonable comproveu les carpetes de spam. <br>Si no és allà, pregunteu a l'administrador local.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Els vostres fitxers estan encriptats. Si no heu habilitat la clau de recuperació no hi haurà manera de recuperar les dades després que reestabliu la contrasenya. <br />Si sabeu què fer, contacteu amb l'administrador abans de continuar.<br />Voleu continuar?",
    "I know what I'm doing" : "Sé el que faig",
    "Password can not be changed. Please contact your administrator." : "La contrasenya no es pot canviar. Contacteu amb l'administrador.",
    "No" : "No",
    "Yes" : "Sí",
    "Choose" : "Escull",
    "Error loading file picker template: {error}" : "Error en carregar la plantilla de càrrega de fitxers: {error}",
    "Ok" : "D'acord",
    "Error loading message template: {error}" : "Error en carregar la plantilla de missatge: {error}",
    "read-only" : "Només de lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicte de fitxer","{count} conflictes de fitxer"],
    "One file conflict" : "Un fitxer en conflicte",
    "New Files" : "Fitxers nous",
    "Already existing files" : "Fitxers que ja existeixen",
    "Which files do you want to keep?" : "Quin fitxer voleu conservar?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccioneu les dues versions, el fitxer copiat tindrà un número afegit al seu nom.",
    "Cancel" : "Cancel·la",
    "Continue" : "Continua",
    "(all selected)" : "(selecciona-ho tot)",
    "({count} selected)" : "({count} seleccionats)",
    "Error loading file exists template" : "Error en carregar la plantilla de fitxer existent",
    "Very weak password" : "Contrasenya massa feble",
    "Weak password" : "Contrasenya feble",
    "So-so password" : "Contrasenya passable",
    "Good password" : "Contrasenya bona",
    "Strong password" : "Contrasenya forta",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "El servidor web no està configurat correctament per permetre la sincronització de fitxers perquè la interfície WebDAV sembla no funcionar correctament.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Aquest servidor no té connexió a internet. Això significa que algunes de les característiques com el muntatge d'emmagatzemament extern, les notificacions quant a actualitzacions o la instal·lació d'aplicacions de tercers no funcionarà. L'accés remot a fitxers i l'enviament de correus electrònics podria tampoc no funcionar. Us suggerim que habiliteu la connexió a internet per aquest servidor si voleu tenir totes les característiques.",
    "Error occurred while checking server setup" : "Hi ha hagut un error en comprovar la configuració del servidor",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "La carpeta de dades i els vostres fitxers probablement són accessibles des d'Internet. El fitxer .htaccess no funciona. Us recomanem que configureu el servidor web de tal manera que la carpeta de dades no sigui accessible o que moveu la carpeta de dades fora de l'arrel de documents del servidor web.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Esteu accedint aquesta web a través de HTTP. Us recomanem que configureu el servidor per requerir HTTPS tal i com es descriu als <a href=\"{docUrl}\">consells de seguretat</a>",
    "Shared" : "Compartit",
    "Shared with {recipients}" : "Compartit amb {recipients}",
    "Error" : "Error",
    "Error while sharing" : "Error en compartir",
    "Error while unsharing" : "Error en deixar de compartir",
    "Error setting expiration date" : "Error en establir la data de venciment",
    "The public link will expire no later than {days} days after it is created" : "L'enllaç públic tindrà venciment abans de {days} dies després de crear-lo",
    "Set expiration date" : "Estableix la data de venciment",
    "Expiration" : "Expiració",
    "Expiration date" : "Data de venciment",
    "Choose a password for the public link" : "Escolliu una contrasenya per l'enllaç públic",
    "Sending ..." : "Enviant...",
    "Email sent" : "El correu electrónic s'ha enviat",
    "Resharing is not allowed" : "No es permet compartir de nou",
    "Share link" : "Enllaç de compartició",
    "Link" : "Enllaç",
    "Password protect" : "Protegir amb contrasenya",
    "Password" : "Contrasenya",
    "Allow editing" : "Permetre edició",
    "Email link to person" : "Enllaç per correu electrónic amb la persona",
    "Send" : "Envia",
    "Shared with you and the group {group} by {owner}" : "Compartit amb vos i amb el grup {group} per {owner}",
    "Shared with you by {owner}" : "Compartit amb vos per {owner}",
    "group" : "grup",
    "remote" : "remot",
    "notify by email" : "notifica per correu electrònic",
    "Unshare" : "Deixa de compartir",
    "can share" : "pot compartir",
    "can edit" : "pot editar",
    "create" : "crea",
    "change" : "canvi",
    "delete" : "elimina",
    "access control" : "control d'accés",
    "An error occured. Please try again" : "Va ocórrer un error. Per favor, intenta-ho de nou",
    "Share" : "Comparteix",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartir amb la gent en altres ownClouds utilitzant la sintaxi username@example.com/owncloud",
    "Share with users or groups …" : "Comparteix amb usuaris o grups ...",
    "Share with users, groups or remote users …" : "Comparteix amb usuaris, grups o usuaris remots ...",
    "Warning" : "Avís",
    "Delete" : "Esborra",
    "Rename" : "Reanomena",
    "The object type is not specified." : "No s'ha especificat el tipus d'objecte.",
    "Enter new" : "Escriu nou",
    "Add" : "Afegeix",
    "Edit tags" : "Edita etiquetes",
    "Error loading dialog template: {error}" : "Error en carregar la plantilla de diàleg: {error}",
    "No tags selected for deletion." : "No heu seleccionat les etiquetes a eliminar.",
    "unknown text" : "text desconegut",
    "Hello world!" : "Hola món!",
    "sunny" : "asolellat",
    "Hello {name}, the weather is {weather}" : "Hola {name}, el temps és {weather}",
    "Hello {name}" : "Hola {name}",
    "_download %n file_::_download %n files_" : ["descarregar l'arxiu %n","descarregar arxius %n "],
    "Updating {productName} to version {version}, this may take a while." : "Actualitzant {productName} a la versió {version}. Pot trigar una estona.",
    "Please reload the page." : "Carregueu la pàgina de nou.",
    "The update was unsuccessful. " : "La actualització no ha tingut èxit",
    "The update was successful. There were warnings." : "La actualització ha estat exitosa. Hi ha alertes.",
    "The update was successful. Redirecting you to ownCloud now." : "L'actualització ha estat correcte. Ara us redirigim a ownCloud.",
    "Searching other places" : "Buscant altres ubicacions",
    "Personal" : "Personal",
    "Users" : "Usuaris",
    "Apps" : "Aplicacions",
    "Admin" : "Administració",
    "Help" : "Ajuda",
    "Error loading tags" : "Error en carregar les etiquetes",
    "Tag already exists" : "L'etiqueta ja existeix",
    "Error deleting tag(s)" : "Error en eliminar etiqueta(s)",
    "Error tagging" : "Error en etiquetar",
    "Error untagging" : "Error en treure les etiquetes",
    "Error favoriting" : "Error en posar a preferits",
    "Error unfavoriting" : "Error en treure de preferits",
    "Access forbidden" : "Accés prohibit",
    "File not found" : "No s'ha trobat l'arxiu",
    "The specified document has not been found on the server." : "El document especificat no s'ha trobat al servidor.",
    "You can click here to return to %s." : "Pots clicar aquí per tornar a %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Ei,\n\nnomés fer-te saber que %s ha compartit %s amb tu.\nMira-ho a: %s\n\n",
    "The share will expire on %s." : "La compartició venç el %s.",
    "Cheers!" : "Salut!",
    "Internal Server Error" : "Error Intern del Servidor",
    "The server encountered an internal error and was unable to complete your request." : "El servidor ha trobat un error intern i no pot finalitzar la teva petició.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Per favor, posi's en contacte amb l'administrador del servidor si aquest error torna a aparèixer diverses vegades, per favor inclogui els detalls tècnics de baix en el seu informe.",
    "More details can be found in the server log." : "Pots trobar més detalls al llistat del servidor.",
    "Technical details" : "Detalls tècnics",
    "Remote Address: %s" : "Adreça remota: %s",
    "Request ID: %s" : "Sol·licitud ID: %s ",
    "Type: %s" : "Tipus: %s",
    "Code: %s" : "Codi: %s",
    "Message: %s" : "Missatge: %s",
    "File: %s" : "Fitxer: %s",
    "Line: %s" : "Línia: %s",
    "Trace" : "Traça",
    "Security warning" : "Advertiment de seguretat",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La carpeta de dades i els seus fitxers probablement són accessibles des d'internet perquè el fitxer .htaccess no funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Per informació de com configurar el servidor, comproveu la <a href=\"%s\" target=\"_blank\">documentació</a>.",
    "Create an <strong>admin account</strong>" : "Crea un <strong>compte d'administrador</strong>",
    "Username" : "Nom d'usuari",
    "Storage & database" : "Emmagatzematge i base de dades",
    "Data folder" : "Carpeta de dades",
    "Configure the database" : "Configura la base de dades",
    "Only %s is available." : "Només hi ha disponible %s",
    "Install and activate additional PHP modules to choose other database types." : "Instal·la i activa mòduls PHP addicionals per seleccionar altres tipus de bases de dades.",
    "For more details check out the documentation." : "Per més detalls consulteu la documentació.",
    "Database user" : "Usuari de la base de dades",
    "Database password" : "Contrasenya de la base de dades",
    "Database name" : "Nom de la base de dades",
    "Database tablespace" : "Espai de taula de la base de dades",
    "Database host" : "Ordinador central de la base de dades",
    "Performance warning" : "Alerta de rendiment",
    "SQLite will be used as database." : "SQLite s'utilitzarà com a base de dades.",
    "For larger installations we recommend to choose a different database backend." : "Per a instal·lacions més grans es recomana triar una base de dades diferent.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "L'ús de SQLite està desaconsellat especialment quan s'usa el client d'escriptori per sincronitzar els fitxers.",
    "Finish setup" : "Acaba la configuració",
    "Finishing …" : "Acabant...",
    "Need help?" : "Necessites ajuda?",
    "See the documentation" : "Consulti la documentació",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Ei, <br><br>només fer-vos saber que %s us ha comparti <strong>%s</strong>. <br><a href=\"%s\">Mireu-ho!</a>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aquesta aplicació requereix Javascript per al seu correcte funcionament . Per favor, {linkstart}habiliti Javascript{linkend} i torni a carregar la pàgina.",
    "Log out" : "Surt",
    "Search" : "Cerca",
    "Server side authentication failed!" : "L'autenticació del servidor ha fallat!",
    "Please contact your administrator." : "Contacteu amb l'administrador.",
    "An internal error occured." : "S'ha produït un error intern.",
    "Please try again or contact your administrator." : "Intenti-ho de nou o posi's en contacte amb el seu administrador.",
    "Log in" : "Inici de sessió",
    "Wrong password. Reset it?" : "Contrasenya incorrecta. Voleu restablir-la?",
    "Wrong password." : "Contrasenya incorrecta.",
    "Stay logged in" : "Mantén la sessió connectada",
    "Alternative Logins" : "Acreditacions alternatives",
    "Use the following link to reset your password: {link}" : "Useu l'enllaç següent per restablir la contrasenya: {link}",
    "New password" : "Contrasenya nova",
    "New Password" : "Contrasenya nova",
    "Reset password" : "Reinicialitza la contrasenya",
    "This ownCloud instance is currently in single user mode." : "La instància ownCloud està en mode d'usuari únic.",
    "This means only administrators can use the instance." : "Això significa que només els administradors poden usar la instància.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacteu amb l'administrador del sistema si aquest missatge persisteix o apareix inesperadament.",
    "Thank you for your patience." : "Gràcies per la paciència.",
    "You are accessing the server from an untrusted domain." : "Esteu accedint al servidor des d'un domini no fiable",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "En funció de la teva configuració, com a administrador podries utilitzar el botó d'abaix per confiar en aquest domini.",
    "Add \"%s\" as trusted domain" : "Afegeix \"%s\" com a domini de confiança",
    "App update required" : "Cal que actualitzeu la aplicació",
    "%s will be updated to version %s" : "%s s'actualitzarà a la versió %s",
    "These apps will be updated:" : "Aquestes aplicacions s'actualitzaran:",
    "These incompatible apps will be disabled:" : "Aquestes aplicacions incompatibles es desactivaran:",
    "The theme %s has been disabled." : "S'ha desactivat el tema %s",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Assegureu-vos que heu fet una còpia de seguretat de la base de dades, del fitxer de configuració i de la carpeta de dades abans de continuar.",
    "Start update" : "Inicia l'actualització",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitar que s'esgoti el temps d'espera en instalacions grans, pots en el seu lloc fer córrer la següent comanda en el directori d'instalació. ",
    "This %s instance is currently in maintenance mode, which may take a while." : "Aquesta instància %s està actualment en manteniment i podria trigar una estona.",
    "This page will refresh itself when the %s instance is available again." : "Aquesta pàgina s'actualitzarà automàticament quan la instància %s estigui disponible de nou.",
    "Repair error: " : "Error de reparació:",
    "Password can not be changed. Please contact your administrator." : "La contrasenya no es pot canviar. Contacteu amb l'administrador."
},
"nplurals=2; plural=(n != 1);");
